@@ -147,8 +147,8 @@ class Client(object):
             'post',
             url=target_url,
             headers={
-                'Content-Type':'application/json'#,
-                #'Authorization':'Basic '+base64.b64encode('{u}:{p}'.format(u=self._app_id, p=self._token)).encode('ascii')
+                'Content-Type':'application/json',
+                'Authorization':'Basic '+base64.b64encode('{u}:{p}'.format(u=self._app_id, p=self._token)).encode('ascii')
             },
             body=arguments
         )
